# Authors

Django Deep Link is written and maintained by Tim Santorand various contributors:

## Development Lead

- Tim Santor <tsantor@xstudios.com>

## Contributors

None yet. Why not be the first?
